import arcade

from importlib import resources

from jacovirt.bot.level import level


class Tile(arcade.Sprite):
    """
    Tile sprite
    """
    def __init__(self, x, y, start_x, start_y, size=100, spacing=10, scale=0.5):
        self.pos = (x, y)

        self.theme = level.get("theme")
        self.sprite = level.get(self.pos)

        with resources.path("jacovirt", 'Img') as img_folder :
            self.image_file_name = f"{img_folder}/bot/{self.theme}/{self.sprite}.png"

        self.size = size
        self.spacing = spacing

        super().__init__(self.image_file_name, scale, hit_box_algorithm="None")
        self.position = (
                start_x + x * (self.size + self.spacing) + self.size / 2,
                start_y + y * (self.size + self.spacing) + self.size / 2
            )

    def debug(self, size=10):
        arcade.draw_text(
            self.pos,
            self.left + self.spacing,
            self.bottom + self.spacing,
            arcade.color.BLACK,
            size,
        )


class Grid():
    """
    Grid object
    """
    def __init__(self, x, y, row=6, column=6, size=100, spacing=10):
        self.row = row
        self.column = column
        self.pos = (x, y)
        self.tiles = arcade.SpriteList()

        for r in range(row):
            for c in range(column):
                self.tiles.append(
                        Tile(
                            x=r,
                            y=c,
                            start_x=x,
                            start_y=y,
                            size=size,
                            spacing=spacing
                        )
                    )
