import arcade
import jacovirt.logger
import logging

from jacovirt.bot.grid import Grid
from jacovirt.bot.bot import Bot

# Screen title and size
SCREEN_TITLE = "JacoVirt Bot"
SCREEN_WIDTH = int(1000)
SCREEN_HEIGHT = int(1000)

# Window color
BACKGROUND_COLOR = arcade.color.CATALINA_BLUE

COLUMN = 6
ROW = 6
SIZE_TILE = 100
SPACING = 10
X_START = (SCREEN_HEIGHT - (SIZE_TILE + SPACING) * ROW) / 2
Y_START = (SCREEN_WIDTH - (SIZE_TILE + SPACING) * COLUMN) / 2


class Window(arcade.Window):
    """Main application class"""

    def __init__(self):
        # Init parent class
        super().__init__(int(SCREEN_WIDTH), int(SCREEN_HEIGHT), SCREEN_TITLE)
        # Set background color
        arcade.set_background_color(BACKGROUND_COLOR)

        self.grid = None
        self.bot = None

    def setup(self):
        """Set up the pad"""
        logging.info("Set up the bot.")

        self.grid = Grid(X_START, Y_START, ROW, COLUMN, SIZE_TILE, SPACING)
        self.bot = Bot((0,5), self.grid)

    def on_draw(self):
        """Render the screen"""

        # Clear the screen
        self.clear()

        # Draw tiles
        self.grid.tiles.draw()

        # If debug log level, draw info for tiles
        if logging.root.level <= logging.DEBUG:
            for tile in self.grid.tiles:
                tile.debug()

        self.bot.draw()

    def on_key_press(self, symbol, modifiers):
        """Called when the user presses key"""
        if symbol == arcade.key.R:
            logging.info("Restart !")
            self.setup()

        if symbol == arcade.key.Q:
            arcade.exit()

        if symbol == arcade.key.LEFT:
            self.bot.left()
        if symbol == arcade.key.RIGHT:
            self.bot.right()
        if symbol == arcade.key.UP:
            self.bot.forward()

def main():
    """Main method"""
    window = Window()
    window.setup()
    arcade.run()
